@@ -29,8 +29,6 @@
 #include <QX11Info>
 #include <QRect>
 
-#include <kdebug.h>
-
 using namespace KScreen;
 
 XRandRConfig::XRandRConfig()
@@ -125,7 +123,7 @@ KScreen::Config *XRandRConfig::toKScreenConfig() const
 
     config->setOutputs(kscreenOutputs);
     config->setScreen(m_screen->toKScreenScreen(config));
-    if (m_primaryOutput != -1 && (!config->primaryOutput() || config->primaryOutput()->id() != m_primaryOutput)) {
+    if (m_primaryOutput != -1 && config->primaryOutput()->id() != m_primaryOutput) {
         config->setPrimaryOutput(kscreenOutputs.value(m_primaryOutput));
     }
 
@@ -164,7 +162,6 @@ void XRandRConfig::updateKScreenConfig(Config *config) const
 
 void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
 {
-    KDebug::Block apply("Applying KScreen Config", dXndr());
     KScreen::OutputList outputs = config->outputs();
     QSize newSize = screenSize(config);
 
@@ -224,11 +221,11 @@ void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
         // this happens, we are adding this debug code to try to
         // figure out how this happened.
         if (!currentMode) {
-            kWarning() << "Current mode is null:"
+            qWarning() << "Current mode is null:"
             << "ModeId:" << currentOutput->currentModeId()
             << "Mode: " << currentOutput->currentMode()
             << "Output: " << currentOutput->id();
-            kDebug() << kRealBacktrace(256);
+//             qDebug() << kRealBacktrace(256);
             printConfig(config);
             printInternalCond();
             return;
@@ -254,7 +251,7 @@ void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
 
         if (x > newSize.width() || y > newSize.height()) {
             if (!toDisable.contains(output->id())) {
-                kDebug(dXndr()) << "Output doesn't fit: " << x << "x" << y << newSize;
+                qCDebug(KSCREEN_XRANDR) << "Output doesn't fit: " << x << "x" << y << newSize;
                 toDisable.insert(output->id(), output);
             }
         }
@@ -263,37 +260,37 @@ void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
     KScreen::Screen* screen = config->screen();
     if (newSize.width() > screen->maxSize().width() ||
         newSize.height() > screen->maxSize().height()) {
-        kDebug(dXndr()) << "The new size is too big: " << newSize << " - " << screen->maxSize();
+        qCDebug(KSCREEN_XRANDR) << "The new size is too big: " << newSize << " - " << screen->maxSize();
         return;//Too big
     }
 
-    kDebug(dXndr()) << neededCrtc;
+    qCDebug(KSCREEN_XRANDR) << neededCrtc;
     XRRScreenResources *screenResources = XRandR::screenResources();
     if (neededCrtc > screenResources->ncrtc) {
-        kDebug(dXndr()) << "We need more crtc than we have: " << neededCrtc << " - " << screenResources->ncrtc;
+        qCDebug(KSCREEN_XRANDR) << "We need more crtc than we have: " << neededCrtc << " - " << screenResources->ncrtc;
         XRRFreeScreenResources(screenResources);
         return;//We don't have enough crtc
     }
     XRRFreeScreenResources(screenResources);
 
-    kDebug(dXndr()) << "Actions to perform: ";
-    kDebug(dXndr()) << "\t Primary Output: " << primaryOutput;
-    kDebug(dXndr()) << "\t Screen Size: " << (newSize != m_screen->currentSize());
+    qCDebug(KSCREEN_XRANDR) << "Actions to perform: ";
+    qCDebug(KSCREEN_XRANDR) << "\t Primary Output: " << primaryOutput;
+    qCDebug(KSCREEN_XRANDR) << "\t Screen Size: " << (newSize != m_screen->currentSize());
     if (newSize != m_screen->currentSize()) {
-        kDebug(dXndr()) << "\t Old: " << m_screen->currentSize();
-        kDebug(dXndr()) << "\t New: " << newSize;
+        qCDebug(KSCREEN_XRANDR) << "\t Old: " << m_screen->currentSize();
+        qCDebug(KSCREEN_XRANDR) << "\t New: " << newSize;
     }
-    kDebug(dXndr()) << "\t Disable outputs: " << !toDisable.isEmpty();
+    qCDebug(KSCREEN_XRANDR) << "\t Disable outputs: " << !toDisable.isEmpty();
     if (!toDisable.isEmpty()) {
-        kDebug(dXndr()) << "\t\t" << toDisable.keys();
+        qCDebug(KSCREEN_XRANDR) << "\t\t" << toDisable.keys();
     }
-    kDebug(dXndr()) << "\t Change outputs: " << !toChange.isEmpty();
+    qCDebug(KSCREEN_XRANDR) << "\t Change outputs: " << !toChange.isEmpty();
     if (!toChange.isEmpty()) {
-        kDebug(dXndr()) << "\t\t" << toChange.keys();
+        qCDebug(KSCREEN_XRANDR) << "\t\t" << toChange.keys();
     }
-    kDebug(dXndr()) << "\t Enable outputs: " << !toEnable.isEmpty();
+    qCDebug(KSCREEN_XRANDR) << "\t Enable outputs: " << !toEnable.isEmpty();
     if (!toEnable.isEmpty()) {
-        kDebug(dXndr()) << "\t\t" << toEnable.keys();
+        qCDebug(KSCREEN_XRANDR) << "\t\t" << toEnable.keys();
     }
 
     setPrimaryOutput(primaryOutput);
@@ -322,7 +319,7 @@ void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
              * to re-enable it, then update screen size too */
             if (toDisable.contains(output->id())) {
                 output->setEnabled(false);
-                kDebug() << "Output failed to change: " << output->name();
+                qCDebug(KSCREEN_XRANDR) << "Output failed to change: " << output->name();
                 forceScreenSizeUpdate = true;
             }
         }
@@ -331,7 +328,7 @@ void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
     Q_FOREACH(KScreen::Output* output, toEnable) {
         if (!enableOutput(output)) {
             output->setEnabled(false);
-            kDebug() << "Output failed to be Enabled: " << output->name();
+            qCDebug(KSCREEN_XRANDR) << "Output failed to be Enabled: " << output->name();
             forceScreenSizeUpdate = true;
         }
     }
@@ -339,126 +336,125 @@ void XRandRConfig::applyKScreenConfig(KScreen::Config *config)
 
     if (forceScreenSizeUpdate) {
         newSize = screenSize(config);
-        kDebug() << "forced to change screen Size: " << newSize;
+        qCDebug(KSCREEN_XRANDR) << "forced to change screen Size: " << newSize;
         setScreenSize(newSize);
     }
 }
 
 void XRandRConfig::printConfig(Config* config) const
 {
-    kDebug() << "KScreen version:" << LIBKSCREEN_VERSION;
+    qCDebug(KSCREEN_XRANDR) << "KScreen version:" /*<< LIBKSCREEN_VERSION*/;
 
     if (!config) {
-        kDebug() << "Config is invalid";
+        qCDebug(KSCREEN_XRANDR) << "Config is invalid";
         return;
     }
     if (!config->screen()) {
-        kDebug() << "No screen in the configuration, broken backend";
+        qCDebug(KSCREEN_XRANDR) << "No screen in the configuration, broken backend";
         return;
     }
 
-    kDebug() << "Screen:";
-    kDebug() << "\tmaxSize:" << config->screen()->maxSize();
-    kDebug() << "\tminSize:" << config->screen()->minSize();
-    kDebug() << "\tcurrentSize:" << config->screen()->currentSize();
+    qCDebug(KSCREEN_XRANDR) << "Screen:";
+    qCDebug(KSCREEN_XRANDR) << "\tmaxSize:" << config->screen()->maxSize();
+    qCDebug(KSCREEN_XRANDR) << "\tminSize:" << config->screen()->minSize();
+    qCDebug(KSCREEN_XRANDR) << "\tcurrentSize:" << config->screen()->currentSize();
 
     OutputList outputs = config->outputs();
     Q_FOREACH(Output *output, outputs) {
-        kDebug() << "\n-----------------------------------------------------\n";
-        kDebug() << "Id: " << output->id();
-        kDebug() << "Name: " << output->name();
-        kDebug() << "Type: " << output->type();
-        kDebug() << "Connected: " << output->isConnected();
+        qCDebug(KSCREEN_XRANDR) << "\n-----------------------------------------------------\n";
+        qCDebug(KSCREEN_XRANDR) << "Id: " << output->id();
+        qCDebug(KSCREEN_XRANDR) << "Name: " << output->name();
+        qCDebug(KSCREEN_XRANDR) << "Type: " << output->type();
+        qCDebug(KSCREEN_XRANDR) << "Connected: " << output->isConnected();
         if (!output->isConnected()) {
             continue;
         }
-        kDebug() << "Enabled: " << output->isEnabled();
-        kDebug() << "Primary: " << output->isPrimary();
-        kDebug() << "Rotation: " << output->rotation();
-        kDebug() << "Pos: " << output->pos();
-        kDebug() << "MMSize: " << output->sizeMm();
+        qCDebug(KSCREEN_XRANDR) << "Enabled: " << output->isEnabled();
+        qCDebug(KSCREEN_XRANDR) << "Primary: " << output->isPrimary();
+        qCDebug(KSCREEN_XRANDR) << "Rotation: " << output->rotation();
+        qCDebug(KSCREEN_XRANDR) << "Pos: " << output->pos();
+        qCDebug(KSCREEN_XRANDR) << "MMSize: " << output->sizeMm();
         if (output->currentMode()) {
-            kDebug() << "Size: " << output->currentMode()->size();
+            qCDebug(KSCREEN_XRANDR) << "Size: " << output->currentMode()->size();
         }
         if (output->clones().isEmpty()) {
-            kDebug() << "Clones: " << "None";
+            qCDebug(KSCREEN_XRANDR) << "Clones: " << "None";
         } else {
-            kDebug() << "Clones: " << output->clones().count();
+            qCDebug(KSCREEN_XRANDR) << "Clones: " << output->clones().count();
         }
-        kDebug() << "Mode: " << output->currentModeId();
-        kDebug() << "Preferred Mode: " << output->preferredModeId();
-        kDebug() << "Preferred modes: " << output->preferredModes();
-        kDebug() << "Modes: ";
+        qCDebug(KSCREEN_XRANDR) << "Mode: " << output->currentModeId();
+        qCDebug(KSCREEN_XRANDR) << "Preferred Mode: " << output->preferredModeId();
+        qCDebug(KSCREEN_XRANDR) << "Preferred modes: " << output->preferredModes();
+        qCDebug(KSCREEN_XRANDR) << "Modes: ";
 
         ModeList modes = output->modes();
         Q_FOREACH(Mode* mode, modes) {
-            kDebug() << "\t" << mode->id() << "  " << mode->name() << " " << mode->size() << " " << mode->refreshRate();
+            qCDebug(KSCREEN_XRANDR) << "\t" << mode->id() << "  " << mode->name() << " " << mode->size() << " " << mode->refreshRate();
         }
 
         Edid* edid = output->edid();
-        kDebug() << "EDID Info: ";
+        qCDebug(KSCREEN_XRANDR) << "EDID Info: ";
         if (edid && edid->isValid()) {
-            kDebug() << "\tDevice ID: " << edid->deviceId();
-            kDebug() << "\tName: " << edid->name();
-            kDebug() << "\tVendor: " << edid->vendor();
-            kDebug() << "\tSerial: " << edid->serial();
-            kDebug() << "\tEISA ID: " << edid->eisaId();
-            kDebug() << "\tHash: " << edid->hash();
-            kDebug() << "\tWidth: " << edid->width();
-            kDebug() << "\tHeight: " << edid->height();
-            kDebug() << "\tGamma: " << edid->gamma();
-            kDebug() << "\tRed: " << edid->red();
-            kDebug() << "\tGreen: " << edid->green();
-            kDebug() << "\tBlue: " << edid->blue();
-            kDebug() << "\tWhite: " << edid->white();
+            qCDebug(KSCREEN_XRANDR) << "\tDevice ID: " << edid->deviceId();
+            qCDebug(KSCREEN_XRANDR) << "\tName: " << edid->name();
+            qCDebug(KSCREEN_XRANDR) << "\tVendor: " << edid->vendor();
+            qCDebug(KSCREEN_XRANDR) << "\tSerial: " << edid->serial();
+            qCDebug(KSCREEN_XRANDR) << "\tEISA ID: " << edid->eisaId();
+            qCDebug(KSCREEN_XRANDR) << "\tHash: " << edid->hash();
+            qCDebug(KSCREEN_XRANDR) << "\tWidth: " << edid->width();
+            qCDebug(KSCREEN_XRANDR) << "\tHeight: " << edid->height();
+            qCDebug(KSCREEN_XRANDR) << "\tGamma: " << edid->gamma();
+            qCDebug(KSCREEN_XRANDR) << "\tRed: " << edid->red();
+            qCDebug(KSCREEN_XRANDR) << "\tGreen: " << edid->green();
+            qCDebug(KSCREEN_XRANDR) << "\tBlue: " << edid->blue();
+            qCDebug(KSCREEN_XRANDR) << "\tWhite: " << edid->white();
         } else {
-            kDebug() << "\tUnavailable";
+            qCDebug(KSCREEN_XRANDR) << "\tUnavailable";
         }
     }
 }
 
 void XRandRConfig::printInternalCond() const
 {
-    kDebug() << "Internal config in xrandr";
+    qCDebug(KSCREEN_XRANDR) << "Internal config in xrandr";
     Q_FOREACH(XRandROutput *output, m_outputs) {
-        kDebug() << "Id: " << output->id();
-        kDebug() << "Current Mode: " << output->currentMode();
-        kDebug() << "Current mode id: " << output->currentModeId();
-        kDebug() << "Connected: " << output->isConnected();
-        kDebug() << "Enabled: " << output->isEnabled();
-        kDebug() << "Primary: " << output->isPrimary();
+        qCDebug(KSCREEN_XRANDR) << "Id: " << output->id();
+        qCDebug(KSCREEN_XRANDR) << "Current Mode: " << output->currentMode();
+        qCDebug(KSCREEN_XRANDR) << "Current mode id: " << output->currentModeId();
+        qCDebug(KSCREEN_XRANDR) << "Connected: " << output->isConnected();
+        qCDebug(KSCREEN_XRANDR) << "Enabled: " << output->isEnabled();
+        qCDebug(KSCREEN_XRANDR) << "Primary: " << output->isPrimary();
         if (!output->isEnabled()) {
             continue;
         }
         XRandRMode::Map modes = output->modes();
         Q_FOREACH(XRandRMode *mode, modes) {
-            kDebug() << "\t" << mode->id();
-            kDebug() << "\t" << mode->name();
-            kDebug() << "\t" << mode->size() << mode->refreshRate();
+            qCDebug(KSCREEN_XRANDR) << "\t" << mode->id();
+            qCDebug(KSCREEN_XRANDR) << "\t" << mode->name();
+            qCDebug(KSCREEN_XRANDR) << "\t" << mode->size() << mode->refreshRate();
         }
     }
 }
 
 QSize XRandRConfig::screenSize(KScreen::Config* config) const
 {
-    KDebug::Block screenBlock("Calculating screen size", dXndr());
     QRect rect;
     QSize outputSize;
     Q_FOREACH(const KScreen::Output* output, config->outputs()) {
         if (!output->isEnabled() || !output->isConnected()) {
-            kDebug(dXndr()) << "Disabled/Disconnected output: " << output->name();
+            qCDebug(KSCREEN_XRANDR) << "Disabled/Disconnected output: " << output->name();
             continue;
         }
 
         Mode *currentMode = output->currentMode();
         if (!currentMode) {
-            kDebug(dXndr()) << "Output: " << output->name() << " has no current Mode";
+            qCDebug(KSCREEN_XRANDR) << "Output: " << output->name() << " has no current Mode";
             continue;
         }
 
         QSize outputSize = currentMode->size();
 
-        kDebug(dXndr()) << "Output: " << output->name() << " Size: " << outputSize << " Pos: " << output->pos();
+        qCDebug(KSCREEN_XRANDR) << "Output: " << output->name() << " Size: " << outputSize << " Pos: " << output->pos();
         if (output->pos().x() < rect.x()) {
             rect.setX(output->pos().x());
         }
@@ -487,24 +483,23 @@ QSize XRandRConfig::screenSize(KScreen::Config* config) const
     }
 
     QSize size = QSize(rect.width(), rect.height());
-    kDebug(dXndr()) << "Requested screen size is" << size;
+    qCDebug(KSCREEN_XRANDR) << "Requested screen size is" << size;
     return size;
 }
 
 bool XRandRConfig::setScreenSize(const QSize& size) const
 {
-    KDebug::Block setBlock("Setting screen size", dXndr());
     double dpi;
     int widthMM, heightMM;
     dpi = (25.4 * DisplayHeight(XRandR::display(), XRandR::screen())) / DisplayHeightMM(XRandR::display(), XRandR::screen());
 
-    kDebug(dXndr()) << "DPI: " << dpi;
-    kDebug(dXndr()) << "Size: " << size;
+    qCDebug(KSCREEN_XRANDR) << "DPI: " << dpi;
+    qCDebug(KSCREEN_XRANDR) << "Size: " << size;
 
     widthMM =  ((25.4 * size.width()) / dpi);
     heightMM = ((25.4 * size.height()) / dpi);
 
-    kDebug(dXndr()) << size << " " << widthMM << "x" << heightMM;
+    qCDebug(KSCREEN_XRANDR) << size << " " << widthMM << "x" << heightMM;
     XRRSetScreenSize(XRandR::display(), XRandR::rootWindow(),
                      size.width(), size.height(), widthMM, heightMM);
 
@@ -518,13 +513,12 @@ void XRandRConfig::setPrimaryOutput(int outputId) const
 
 bool XRandRConfig::disableOutput(Output* output) const
 {
-    KDebug::Block disablock("Disable output", dXndr());
     int crtcId = XRandR::outputCrtc(output->id());
-    kDebug(dXndr()) << "Disabling: " << output->id() << "(CRTC" << crtcId << ")";
+    qCDebug(KSCREEN_XRANDR) << "Disabling: " << output->id() << "(CRTC" << crtcId << ")";
     Status s = XRRSetCrtcConfig (XRandR::display(), XRandR::screenResources(), crtcId, CurrentTime,
                  0, 0, None, RR_Rotate_0, NULL, 0);
 
-    kDebug(dXndr()) << "XRRSetCrtcConfig() returned" << s;
+    qCDebug(KSCREEN_XRANDR) << "XRRSetCrtcConfig() returned" << s;
 
     // Update the cached output now, otherwise we get RRNotify_CrtcChange notification
     // for an outdated output, which can lead to a crash.
@@ -536,22 +530,20 @@ bool XRandRConfig::disableOutput(Output* output) const
 
 bool XRandRConfig::enableOutput(Output* output) const
 {
-    KDebug::Block disablock("Enable output", dXndr());
-    kDebug(dXndr()) << "Enabling: " << output->id();
+    qCDebug(KSCREEN_XRANDR) << "Enabling: " << output->id();
     RROutput *outputs = new RROutput[1];
     outputs[0] = output->id();
     Status s = XRRSetCrtcConfig(XRandR::display(), XRandR::screenResources(), XRandR::freeCrtc(output->id()),
         CurrentTime, output->pos().rx(), output->pos().ry(), output->currentModeId().toInt(),
         output->rotation(), outputs, 1);
 
-    kDebug(dXndr()) << "XRRSetCrtcConfig() returned" << s;
+    qCDebug(KSCREEN_XRANDR) << "XRRSetCrtcConfig() returned" << s;
     return (s == RRSetConfigSuccess);
 }
 
 bool XRandRConfig::changeOutput(Output* output, int crtcId) const
 {
-    KDebug::Block disablock("Change output", dXndr());
-    kDebug(dXndr()) << "Updating: " << output->id() << "with CRTC" << crtcId;
+    qCDebug(KSCREEN_XRANDR) << "Updating: " << output->id() << "with CRTC" << crtcId;
 
     RROutput *outputs = new RROutput[1];
     outputs[0] = output->id();
@@ -559,7 +551,7 @@ bool XRandRConfig::changeOutput(Output* output, int crtcId) const
         CurrentTime, output->pos().rx(), output->pos().ry(), output->currentModeId().toInt(),
         output->rotation(), outputs, 1);
 
-    kDebug(dXndr()) << "XRRSetCrtcConfig() returned" << s;
+    qCDebug(KSCREEN_XRANDR) << "XRRSetCrtcConfig() returned" << s;
     return (s == RRSetConfigSuccess);
 }
 
