@@ -22,13 +22,15 @@
 #include "xlibandxcb.h"
 #include "../abstractbackend.h"
 #include <QtCore/QObject>
+#include <QLoggingCategory>
 
-class XRandRX11Helper;
+class XRandRXCBHelper;
 
 class XRandR11 : public QObject, public AbstractBackend
 {
     Q_OBJECT
     Q_INTERFACES(AbstractBackend)
+    Q_PLUGIN_METADATA(IID "org.kf5.kscreen.backends.xrandr11")
 
 public:
     explicit XRandR11(QObject* parent = 0);
@@ -46,10 +48,10 @@ private Q_SLOTS:
 
 private:
     bool m_valid;
-    XRandRX11Helper* m_x11Helper;
+    XRandRXCBHelper* m_x11Helper;
     KScreen::Config* m_currentConfig;
     xcb_timestamp_t m_currentTimestamp;
 };
 
-extern int dXndr();
+Q_DECLARE_LOGGING_CATEGORY(KSCREEN_XRANDR11)
 #endif //FAKE_BACKEND_H
